package smash.appointment.parse;

import java.util.ArrayList;
import java.util.Calendar;
import java.util.List;

import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.Row;

public class PrcFlyingParser extends SubjectParser {

	@Override
	protected String parseScreeningNumber(Row row) {
		String number = getString(row.getCell(25));
		if (number.trim().isEmpty()) {
			return "";
		} else {
			return "P-" + number;
		}
	}

	@Override
	protected String parseName(Row row) {
		return "";
	}

	@Override
	protected String parseSurname(Row row) {
		return getString(row.getCell(0));
	}

	@Override
	protected String parseNdNumber(Row row) {
		return getString(row.getCell(23));
	}

	@Override
	protected String getSheetName() {
		return "Leudelange";
	}

	@Override
	protected int getInitRow() {
		return 2;
	}

	@Override
	protected String parseBirthDate(Row row) {
		return parseDateOfBirth(row.getCell(27));
	}

	@Override
	protected String parsemPowerId(Row row) {
		return "";
	}

	@Override
	protected String parseAddDate(Row row) {
		return getDate(row.getCell(11),Calendar.getInstance());
	}

	@Override
	protected String parseReferal(Row row) {
		return getString(row.getCell(10));
	}

	@Override
	protected String parseDiagnosisYear(Row row) {
		return getString(row.getCell(8));
	}

	@Override
	protected String parseMail(Row row) {
		return getString(row.getCell(6));
	}

	@Override
	protected String parsePhone3(Row row) {
		String phones[] = getPhones(row);
		if (phones.length > 2) {
			return phones[2].trim();
		}
		return "";
	}

	private String[] getPhones(Row row) {
		return getString(row.getCell(5)).split("/");
	}

	@Override
	protected String parsePhone2(Row row) {
		String phones[] = getPhones(row);
		if (phones.length > 1) {
			return phones[1].trim();
		}
		return "";
	}

	@Override
	protected String parsePhone1(Row row) {
		String phones[] = getPhones(row);
		return phones[0].trim();
	}

	@Override
	protected String parseCity(Row row) {
		return getString(row.getCell(3));
	}

	@Override
	protected String parseCountry(Row row) {
		return getString(row.getCell(4));
	}

	@Override
	protected String parseZipCode(Row row) {
		return getString(row.getCell(2));
	}

	@Override
	protected String parseAddress(Row row) {
		return getString(row.getCell(1));
	}

	@Override
	protected String parseRemarks(Row row) {
		String remark1 = getString(row.getCell(7));
		String remark2 = getString(row.getCell(18));

		String result = "";
		if (!remark1.trim().isEmpty()) {
			result = result + remark1 + "\n";
		}
		if (!remark2.trim().isEmpty()) {
			result = result + remark2 + "\n";
		}
		return result;
	}

	@Override
	protected String parseDiagnosis(Row row) {
		return getString(row.getCell(9));
	}

	@Override
	protected SubjectType parseType(Row row) {
		String name = (parseName(row) + " " + parseSurname(row)).toLowerCase();
		if (name.indexOf("(c)") >= 0 || name.indexOf("©") >= 0) {
			return SubjectType.CONTROL;
		} else {
			return SubjectType.SUBJECT;
		}
	}

	@Override
	protected List<String> parseLanguages(Row row) {
		return new ArrayList<>();
	}
	@Override
	protected String parseToBeSeenAt(Row row) {
		return "P";
	}

	@Override
	protected boolean parseDead(Row row) {
		return false;
	}

	@Override
	protected boolean parseResigned(Row row) {
		return false;
	}

}
